@@ -42,7 +42,8 @@
 		     rmail-update-summary url-retrieve
 		     temp-directory babel-fetch babel-wash
 		     find-coding-systems-for-charsets sc-cite-regexp
-		     vcard-pretty-print))
+		     vcard-pretty-print image-type-available-p
+		     make-overlay overlay-put))
       (maybe-bind '(global-face-data
 		    mark-active transient-mark-mode mouse-selection-click-count
 		    mouse-selection-click-count-buffer buffer-display-table
@@ -94,7 +95,7 @@
 		 rmail-summary-exists rmail-select-summary rmail-update-summary
 		 url-generic-parse-url valid-image-instantiator-format-p
 		 babel-fetch babel-wash babel-as-string sc-cite-regexp
-		 vcard-pretty-print)))
+		 vcard-pretty-print image-type-available-p)))
 
 (setq load-path (cons "." load-path))
 (require 'custom)
